@@ -81,6 +81,44 @@ method will be called from the main module of your app project for to
 start the framework app instance.
 
 
+key press event dispatching
+___________________________
+
+For to provide a on_key_press event to the applications that will use the new
+GUI framework you have to catch the key press events of the framework,
+convert/normalize them and then call the :meth:`~MainAppBase.key_press_from_framework`
+with the normalized modifiers and key args.
+
+The :paramref:`~MainAppBase.key_press_from_framework.modifiers` arg is a string
+that can contain several of the following sub-strings, always in the alphabetic
+order (like listed below):
+
+* Alt
+* Ctrl
+* Meta
+* Shift
+
+The :paramref:`~MainAppBase.key_press_from_framework.key` arg is a string
+that is specifying the last pressed key. If the key is not representing
+not a single character but a command key, then `key` will be one of the
+following strings:
+
+* escape
+* tab
+* backspace
+* enter
+* del
+* enter
+* up
+* down
+* right
+* left
+* home
+* end
+* pgup
+* pgdown
+
+
 application status
 ------------------
 
@@ -217,7 +255,7 @@ from ae.console import ConsoleApp                   # type: ignore
 from ae.files import FilesRegister, RegisteredFile  # type: ignore
 
 
-__version__ = '0.0.10'
+__version__ = '0.0.12'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -231,10 +269,12 @@ APP_STATE_CURRENT_VERSION = 2                   #: current application state ver
 MIN_FONT_SIZE = 15.0                            #: minimum font size in pixels
 MAX_FONT_SIZE = 99.0                            #: maximum font size in pixels
 
-THEME_LIGHT_BACKGROUND_COLOR = (1, 1, 1, 1)     #: light theme background color in rgba(0.0 ... 1.0)
-THEME_LIGHT_FONT_COLOR = (0, 0, 0, 1)           #: light theme font color in rgba(0.0 ... 1.0)
-THEME_DARK_BACKGROUND_COLOR = (0, 0, 0, 1)      #: dark theme background color in rgba(0.0 ... 1.0)
-THEME_DARK_FONT_COLOR = (1, 1, 1, 1)            #: dark theme font color in rgba(0.0 ... 1.0)
+COLOR_BLACK = (0.009, 0.006, 0.003, 1.0)        # for to differentiate from framework pure black/white colors
+COLOR_WHITE = (0.999, 0.996, 0.993, 1.0)
+THEME_DARK_BACKGROUND_COLOR = COLOR_BLACK       #: dark theme background color in rgba(0.0 ... 1.0)
+THEME_DARK_FONT_COLOR = COLOR_WHITE             #: dark theme font color in rgba(0.0 ... 1.0)
+THEME_LIGHT_BACKGROUND_COLOR = COLOR_WHITE      #: light theme background color in rgba(0.0 ... 1.0)
+THEME_LIGHT_FONT_COLOR = COLOR_BLACK            #: light theme font color in rgba(0.0 ... 1.0)
 
 
 check_all()     # let ae_updater module check/install any outstanding updates or new app versions
@@ -326,6 +366,7 @@ class MainAppBase(ConsoleApp, ABC):
         """
         if self.framework_app:
             if hasattr(self.framework_app, 'ae_states'):            # has observable DictProperty duplicates
+                # noinspection PyUnresolvedReferences
                 self.framework_app.ae_states[name] = value
             if hasattr(self.framework_app, 'ae_state_' + name):     # has observable attribute duplicate
                 setattr(self.framework_app, 'ae_state_' + name, value)
@@ -379,6 +420,14 @@ class MainAppBase(ConsoleApp, ABC):
             return self.sound_files(sound_name)
         return None
 
+    def key_press_from_framework(self, modifiers: str, key: str):
+        """ dispatch key press event, coming normalized from the UI framework. """
+        event_name = f'on_key_press_of_{modifiers}_{key}'
+        en_lower = event_name.lower()
+        if not self.call_event(event_name):
+            if event_name == en_lower or not self.call_event(en_lower):
+                self.call_event('on_key_press', modifiers, key)
+
     def load_app_states(self):
         """ load application state for to prepare app.run_app """
         app_state = dict()
